==> softcorp_flutter_core-1.0.105.tar.gz: lib/constants.dart <==
import 'package:flutter/material.dart';

// shape values
const defaultPadding = 16.0;
const defaultElevation = 5.0;
const defaultCardPadding = 10.0;
const defaultCornerRadius = 10.0;
const defaultBorderWidth = 1.2;
// color theme
const Color defaultShadow = Color(0xff5e5e5e);
const Color defaultBorderColor = Color(0xff5e5e5e);
const Color defaultDarkColor = Color(0xff212121);

Color avatarBackground = Color(0xffdde4e8);
Color iconColor = Color(0xff637381);
const borderColor = Color(0xffe4e8eb);

const Color defaultBackgroundColor = Color(0xffdcdcdc);
const Color defaultCardColor = Colors.white;

const defaultDangerColor = Colors.redAccent;
const defaultSuccessColor = Color(0xFF1abc9c);
const defaultPrimaryColor = Color(0xff396fee);

const defaultTitleColor = Colors.black;
const defaultSubTitleColor = Color(0xff323232);

const defaultBodyColor = Colors.black;
const secondaryBodyColor = Colors.white;

const softcorpPrimaryColor = Color(0xff245bcb);
const softcorpSecondaryColor = Color(0xff58b4df);
const softcorpIntermediateColor = Color(0xff2ebf91);

const Color darkColorOne = Color(0xFF383F6B);
const Color darkColorTwo = Color(0xFF272C4B);
const Color darkColorThree = Color(0xFF181C2F);

// color arrays
const softcorpGradientColorsOne = [
  softcorpPrimaryColor,
  softcorpSecondaryColor,
];

const softcorpGradientColorsTwo = [
  softcorpPrimaryColor,
  softcorpSecondaryColor,
  softcorpIntermediateColor,
];

const darkGradient = [
  darkColorOne,
  darkColorTwo,
  darkColorThree,
];

// gradients
const softcorpLinearGradient = LinearGradient(
  begin: Alignment.topLeft,
  end: Alignment.centerRight,
  colors: softcorpGradientColorsOne,
);

const softcorpLinearGradientTwo = LinearGradient(
  begin: Alignment.topLeft,
  end: Alignment.centerRight,
  colors: softcorpGradientColorsTwo,
);

const darkLinearGradient = LinearGradient(
  begin: Alignment.topLeft,
  end: Alignment.centerRight,
  colors: darkGradient,
);

==> softcorp_flutter_core-1.0.107.tar.gz: lib/constants.dart <==
import 'package:flutter/material.dart';

// shape values
const defaultPadding = 16.0;
const defaultElevation = 5.0;
const defaultCardPadding = 10.0;
const defaultCornerRadius = 10.0;
const defaultBorderWidth = 1.2;
// color theme
const Color defaultShadow = Color(0xff5e5e5e);
const Color defaultBorderColor = Color(0xffc9c9c9);
const Color defaultFormHoverColor = Color(0xffd7d7d7);
const Color defaultDarkColor = Color(0xff212121);

Color avatarBackground = Color(0xffdde4e8);
Color iconColor = Color(0xff637381);
const borderColor = Color(0xffe4e8eb);

const Color defaultBackgroundColor = Color(0xffF8F8F8);
const Color defaultCardColor = Colors.white;

const defaultDangerColor = Colors.redAccent;
const defaultSuccessColor = Color(0xFF1abc9c);
const defaultPrimaryColor = Color(0xff396fee);

const defaultTitleColor = Colors.black;
const defaultSubTitleColor = Color(0xff323232);

const defaultBodyColor = Colors.black;
const secondaryBodyColor = Colors.white;

const softcorpPrimaryColor = Color(0xff245bcb);
const softcorpSecondaryColor = Color(0xff58b4df);
const softcorpIntermediateColor = Color(0xff2ebf91);

const Color darkColorOne = Color(0xFF383F6B);
const Color darkColorTwo = Color(0xFF272C4B);
const Color darkColorThree = Color(0xFF181C2F);

// color arrays
const softcorpGradientColorsOne = [
  softcorpPrimaryColor,
  softcorpSecondaryColor,
];

const softcorpGradientColorsTwo = [
  softcorpPrimaryColor,
  softcorpSecondaryColor,
  softcorpIntermediateColor,
];

const darkGradient = [
  darkColorOne,
  darkColorTwo,
  darkColorThree,
];

// gradients
const softcorpLinearGradient = LinearGradient(
  begin: Alignment.topLeft,
  end: Alignment.centerRight,
  colors: softcorpGradientColorsOne,
);

const softcorpLinearGradientTwo = LinearGradient(
  begin: Alignment.topLeft,
  end: Alignment.centerRight,
  colors: softcorpGradientColorsTwo,
);

const darkLinearGradient = LinearGradient(
  begin: Alignment.topLeft,
  end: Alignment.centerRight,
  colors: darkGradient,
);
